Change Log — badsnakes - v0.2.0 Documentation

# Change Log

- 0.2.0 - Updates relating to semi-colons and how log files are created. by j_berendt at 2025-03-14 14:15:18

      BADS-4: Semi-colon analysis to be less sensitive
      - The “;” keyword has been removed from the [analyser.constant.suspect]
        section of config.toml. This has not been replaced as the
        CodeTextAnalyser performs a semi-colon rate check vs the number of lines
        in the module, which has a 10% rate in the current v[0.1.0,] config file.

      BADS-2: Fix documentation links
      - The 'Documentation' link on PyPI has been updated to link to
        readthedocs rather than GitHub, as the documentation is now ready.
      - The PyPI link for older releases in the docs has been updated to link to
        #history rather than #files.

      BADS-5, BADS-6: Log filenames and log content
      - The previous generic log filenames were proving ineffective for future
        analysis or audit purposes. A change has been made to create a log file
        specific to a wheel, using the wheel's filename as part of the log
        filename. Similar logic applied to single directories and single modules.
        However, multiple single modules will carry a generic log filename.
      - For example, when analysing ppk output from /tmp/<hash>/*.whl, the
        results from each analysed wheel will be written to individual log files
        with each filename carrying the name of the wheel, along with a datetime
        stamp.

      BADS-7: Log path specified as a CLI argument
      - A new CLI argument has been added (--logpath) which provides the
        directory into which log files are to be stored. This provides an
        alternative to the default of the user's desktop.

      Released: 2025-03-14

- 0.1.0 - Initial development for module, wheel and directory analysis complete. by j_berendt at 2024-11-29 15:45:25

      The following tasks have been implemented at both an installed library and
      CLI tool level:
      - Argument parsing
      - File collection
      - Code parsing
      - Code extraction
      - Analysis
      - Reporting
      - Logging

      Documentation:
      - Initial documentation complete.

      Released: 2025-01-03

- 0.0.0.dev1 - Initial commit for the project placeholder. by j_berendt at 2024-10-04 16:54:22